app/soc/models/notification.py
changeset 737 4c78ee183eb6
parent 726 ba3d399ec9be
child 748 f00e6b3af5a6
--- a/app/soc/models/notification.py	Sat Dec 13 13:28:01 2008 +0000
+++ b/app/soc/models/notification.py	Sat Dec 13 14:55:00 2008 +0000
@@ -53,6 +53,6 @@
   created_on = db.DateTimeProperty(auto_now_add=True,
       verbose_name=ugettext_lazy('Created On'))
   
-  # boolean property that marks if the notification has been read
-  has_been_read = db.BooleanProperty(default=False,
-      verbose_name=ugettext_lazy('Read'))
+  # boolean property that marks if the notification is unread
+  unread = db.BooleanProperty(default=True,
+      verbose_name=ugettext_lazy('Unread'))